OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Sólo visible para las personas que coincidan con la integración del número de teléfono a través de Talk en el móvil",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Sólo visible para las personas de esta instancia e invitados",
    "Federated" : "Federado",
    "Only synchronize to trusted servers" : "Sincronizar solo con servidores de confianza",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar con servidores de confianza y con la libreta de direcciones global y pública",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando…",
    "Unable to change password" : "No se ha podido cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña normal",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "Groups" : "Grupos",
    "Group list is empty" : "La lista de grupos está vacía",
    "Unable to retrieve the group list" : "No se ha podido recuperar la lista de grupos.",
    "{actor} added you to group {group}" : "{actor} te ha añadido al grupo {group}",
    "You added {user} to group {group}" : "Has añadido a {user} al grupo {group}",
    "{actor} added {user} to group {group}" : "{actor} ha añadido a {user} al grupo {group}",
    "An administrator added you to group {group}" : "Un administrador te ha añadido al grupo {group}",
    "An administrator added {user} to group {group}" : "Un administrador ha añadido a {user} al grupo {group}",
    "{actor} removed you from group {group}" : "{actor} te ha eliminado del grupo {group}",
    "You removed {user} from group {group}" : "Has eliminado a {user} del grupo {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha eliminado a {user} del grupo {group}",
    "An administrator removed you from group {group}" : "Un administrador te ha eliminado del grupo {group}",
    "An administrator removed {user} from group {group}" : "Un administrador ha eliminado a {user} del grupo {group}",
    "Your <strong>group memberships</strong> were modified" : "Se han modificado tus <strong>pertenencias a grupos</strong>.",
    "{actor} changed your password" : "{actor} cambió tu contraseña",
    "You changed your password" : "Has cambiado tu contraseña",
    "Your password was reset by an administrator" : "Tu contraseña ha sido restablecida por un administrador",
    "Your password was reset" : "Su contraseña ha sido reiniciada.",
    "{actor} changed your email address" : "{actor} cambió tu dirección de correo electrónico",
    "You changed your email address" : "Has cambiado tu cuenta de correo",
    "Your email address was changed by an administrator" : "Tu cuenta de correo ha sido cambiada por un administrador",
    "You created app password \"{token}\"" : "Has creado la contraseña de app \"{token}\"",
    "An administrator created app password \"{token}\"" : "Un administrador ha creado la contraseña de app \"{token}\"",
    "You deleted app password \"{token}\"" : "Has eliminado la contrasña de app \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Has renombrado la contrasena de app \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Has concedido acceso al sistema de archivos a la contraseña de app \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Has revocado el acceso al sistema de archivos a la contraseña de app \"{token}\"",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión usando la verificación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "El intento de inicio de sesión usando la autenticación en dos pasos (%1$s) ha fallado",
    "Remote wipe was started on %1$s" : "El borrado remoto se inició en %1$s",
    "Remote wipe has finished on %1$s" : "El borrado remoto finalizó en %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>dirección de correo</strong> fue modificada",
    "Could not remove app." : "No se ha podido eliminar la app.",
    "Could not update app." : "No se ha podido actualizar la app.",
    "Wrong password" : "Contraseña incorrecta",
    "Unable to change personal password" : "No se ha podido cambiar la contraseña",
    "Saved" : "Guardado",
    "No user supplied" : "No se especificó un usuario",
    "Unable to change password. Password too long." : "No se puede cambiar la contraseña. La contraseña es demasiado larga.",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor, asigna una contraseña de recuperación del administrador; si no lo haces, se perderán todos los datos de los usuarios.",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor comprueba la contraseña e inténtalo de nuevo.",
    "Backend does not support password change, but the user's encryption key was updated." : "El motor no soporta el cambio de contraseña, pero se ha actualizado la clave de cifrado.",
    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalando y actualizando las apps a través de la App Store o la nube compartida federada",
    "Federated Cloud Sharing" : "Compartido en Nube Federada",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está usando una versión desactualizada %1$s (%2$s). Por favor, actualiza tu sistema operativo o funciones como %3$s no funcionarán de forma fiable.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "No se ha podido determinar si la versión TLS de cURL está desactualizada porque ha ocurrido un error durante la solicitud HTTPS a https://nextcloud.com. Por favor, comprueba el archivo de registro de Nextcloud para más detalles.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "El módulo PHP OPcache no está cargado. Para un mejor rendimiento se recomienda cargarlo en su instalación de PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache está deshabilitado. Para un mejor rendimiento, se recomienda aplicar <code>opcache.enable=1</code> a la configuración de PHP.",
    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache está configurado para eliminar los comentarios del código. Con OPcache activado, se debe establecer <code>opcache.save_comments=1</code> para que Nextcloud funcione.",
    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no puede utilizar la API de OPcache. Con OPcache habilitado, es muy recomendable incluir todos los directorios de Nextcloud con  <code>opcache.restrict_api</code> o deshabilitar este ajuste para desactivar las restricciones de la API de OPcache, para evitar errores durante las actualizaciones del núcleo o de las aplicaciones de Nextcloud.",
    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud no puede utilizar la API de OPcache. Con OPcache habilitado, es muy recomendable incluir todos los directorios de Nextcloud con  <code>opcache.restrict_api</code> o deshabilitar este ajuste para desactivar las restricciones de la API de OPcache, para evitar errores durante las actualizaciones del núcleo o de las aplicaciones de Nextcloud.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "El número máximo de claves de OPcache está casi superado. Para asegurar que todos los scripts puedan mantenerse en la caché, se recomienda aplicar  <code>opcache.max_accelerated_files</code> a su configuración de PHP con un valor superior a <code>%s</code>.",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "El buffer de OPcache está casi lleno. Para asegurar que todos los scripts puedan ser retenidos en la caché, se recomienda aplicar  <code>opcache.memory_consumption</code> a su configuración de PHP con un valor superior a <code>%s</code>.",
    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "El buffer de OPcache está casi lleno. Para asegurar que todos los scripts puedan ser retenidos en la caché, se recomienda aplicar  <code>opcache.memory_consumption</code> a su configuración de PHP con un valor superior a <code>%s</code>.",
    "Invalid SMTP password." : "Contraseña SMTP inválida",
    "Email setting test" : "Prueba de configuración de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si recibes este correo, la configuración de correo parece ser correcta.",
    "Email could not be sent. Check your mail server log" : "No se ha podido enviar el correo. Compruebe el registro del servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ha ocurrido  un problema al enviar el mensaje de correo electrónico. Revisa tu configuración. (Error: %s)",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "Necesitas configurar tu correo antes de poder enviar mensajes de prueba. Ve a %s para ello.",
    "Invalid user" : "Usuario no válido",
    "Invalid mail address" : "Dirección de correo no válido",
    "Settings saved" : "Ajustes guardados",
    "Unable to change full name" : "No se puede cambiar el nombre completo",
    "Unable to change email address" : "No se pudo cambiar la dirección de correo",
    "Unable to set invalid phone number" : "No se pudo establecer un número de teléfono incorrecto",
    "Unable to set invalid website" : "No se pudo establecer una página web incorrecta",
    "Some account data was invalid" : "Algunos datos de la cuenta no son correctos",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para verificar tu cuenta de Twitter, escribe el siguiente tuit en Twitter (por favor, asegúrate de escribirlo sin saltos de línea):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para verificar tu sitio web, guarda el siguiente contenido en la raíz de la web en '.well-known/CloudIdVerificationCode.txt' (por favor, asegúrate de que el texto completo está en una línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió su contraseña en %2$s.",
    "Your password on %s was changed." : "Su contraseña en %s fue cambiada.",
    "Your password on %s was reset by an administrator." : "Su contraseña en %s fue restaurada por un administrador.",
    "Your password on %s was reset." : "Su contraseña en %s ha sido reiniciada.",
    "Password for %1$s changed on %2$s" : "La contraseña para %1$s fue cambiada en %2$s",
    "Password changed for %s" : "Contraseña cambiada por %s",
    "If you did not request this, please contact an administrator." : "Si no has solicitado esto, por favor, ponte en contacto con el administrador.",
    "Your email address on %s was changed." : "Su dirección de correo electrónico en %s fue cambiada.",
    "Your email address on %s was changed by an administrator." : "Su dirección de correo electrónico en %s fue cambiada por un administrador.",
    "Email address for %1$s changed on %2$s" : "Dirección de correo electrónico para %1$s cambiada en %2$s",
    "Email address changed for %s" : "Dirección de correo eletrónico cambiada para %s",
    "The new email address is %s" : "La nueva direción de correo eletrónica es %s",
    "Your %s account was created" : "Se ha creado su cuenta de %s",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta de %s, puedes añadir, proteger y compartir tus datos.",
    "Your username is: %s" : "Su nombre de usuario es: %s",
    "Set your password" : "Establezca su contraseña",
    "Go to %s" : "Vaya a %s",
    "Install Client" : "Instalar cliente",
    "Logged in user must be a subadmin" : "El usuario registrado debe ser un subadministrador",
    "Apps" : "Apps",
    "Settings" : "Ajustes",
    "Personal" : "Personal",
    "Administration" : "Administración",
    "Additional settings" : "Configuración adicional",
    "Administration privileges" : "Privilegios de administración",
    "Groupware" : "Groupware",
    "Overview" : "Vista general",
    "Basic settings" : "Ajustes básicos",
    "Sharing" : "Compartir",
    "Availability" : "Disponibilidad",
    "Personal info" : "Información personal",
    "Mobile & desktop" : "Móvil y escritorio",
    "Email server" : "Servidor de correo electrónico",
    "Security & setup warnings" : "Avisos de seguridad y configuración",
    "Background jobs" : "Trabajos en segundo plano",
    "Create" : "Crear",
    "Change" : "Cambiar",
    "Delete" : "Eliminar",
    "Reshare" : "Volver a compartir",
    "Unlimited" : "Ilimitado",
    "Verifying" : "Verificar",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendiente una tarea en segundo plano que comprueba por el usuario los certificados SSL importados. Por favor, revisalo más tarde.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hay algunos certificados SSL importados por el usuario que ya no se utilizan con Nextcloud 21. Pueden ser importados con la línea de comandos a través del comando \"occ security:certificates:import\". Sus rutas dentro del directorio de datos se muestran a continuación.",
    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Se han encontrado UUIDs no válidos de usuarios o grupos. Por favor, comprueba la configuración de \"Anular detección de UUID\" en la sección de Experto de la configuración LDAP y usa \"occ ldap:update-uuid\" para actualizarlos.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "El antiguo formato de cifrado en el lado del servidor está activado. Recomendamos deshabilitar esto.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Está instalada la versión MariaDB \"%s\". Nextcloud 21 ya no soporta esta versión y requiere MariaDB 10.2 o superior.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Se utiliza la versión \"%s\" de MySQL. Nextcloud 21 ya no soportará esta versión y requiere MySQL 8.0 o MariaDB 10.2 o superior.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Está instalada la versión PostgreSQL \"%s\". Nextcloud 21 ya no soporta esta versión y requiere PostgreSQL 9.6  o superior.",
    "Profile information" : "Información del perfil",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Foto del perfil, nombre completo, correo electrónico, número de teléfono, dirección, sitio web, Twitter, organización, función, titular, biografía y si su perfil está habilitado",
    "Nextcloud settings" : "Ajustes de Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Aquí puedes decidir qué grupo puede acceder a determinadas secciones de la configuración de administración.",
    "None" : "Ninguno",
    "Unable to modify setting" : "No se ha podido modificar la configuración",
    "Two-Factor Authentication" : "Verificación en dos pasos",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "La verificación en dos pasos se puede aplicar para todos los usuarios y grupos específicos. Si no tienen configurado un proveedor de dos pasos, no podrán iniciar sesión en el sistema.",
    "Enforce two-factor authentication" : "Imponer verificación en dos pasos",
    "Limit to groups" : "Límite para grupos",
    "Enforcement of two-factor authentication can be set for certain groups only." : "La obligatoriedad de la autenticación de dos pasos puede establecerse solo para ciertos grupos.",
    "Two-factor authentication is enforced for all members of the following groups." : "La autenticación de dos pasos es obligatoria para todos los miembros de los siguientes grupos.",
    "Enforced groups" : "Grupos obligados",
    "Two-factor authentication is not enforced for members of the following groups." : "La autenticación de dos pasos no es obligatoria para los miembros de los siguientes grupos.",
    "Excluded groups" : "Grupos excluidos",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cuando los grupos se seleccionan/excluyen, usan la siguiente lógica para determinar si un usuario tiene obligada la 2FA: si no hay grupos seleccionados, 2FA está activa para todos excepto los miembros de los grupos excluidos. Si hay grupos seleccionados, 2FA está activa para todos los miembros de estos. Si un usuaro está a la vez en un grupo seleccionado y otro excluido, el seleccionado tiene preferencia y se obliga la 2FA.",
    "Save changes" : "Guardar cambios",
    "All" : "Todos",
    "Limit app usage to groups" : "Limitar uso de apps a grupos",
    "No results" : "No hay resultados",
    "Update to {version}" : "Actualizar a {version}",
    "Remove" : "Eliminar",
    "Disable" : "Desactivar",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app no tiene una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app no tiene una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede instalarse porque las siguientes dependencias no están cumplimentadas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visite el sitio web",
    "Report a bug" : "Notificar un error",
    "User documentation" : "Documentación de usuario",
    "Admin documentation" : "Documentación de administrador",
    "Developer documentation" : "Documentación de desarrollador",
    "This app is supported via your current Nextcloud subscription." : "Esta App está soportada a través de su suscripción actual de Nexcloud.",
    "Supported" : "Soportada",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las apps destacadas están desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad central y están listas para usarlas en producción.",
    "Featured" : "Destacadas",
    "Update to {update}" : "Actualizar a {update}",
    "All apps are up-to-date." : "Todas las apps están actualizadas.",
    "Results from other categories" : "Resultados de otras categorías",
    "No apps found for your version" : "No se han encontrado aplicaciones para su versión",
    "Disable all" : "Deshabilitar todos",
    "Enable all" : "Activar todas",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n app tiene una actualización disponible.","%n apps tienen una actualización disponible.","%n apps tienen una actualización disponible."],
    "_Update_::_Update all_" : ["Actualizar todo","Actualizar todo","Actualizar todo"],
    "Marked for remote wipe" : "Marcado para borrado remoto",
    "Device settings" : "Configuración del dispositivo",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Rename" : "Renombrar",
    "Revoke" : "Anular",
    "Wipe device" : "Borrar dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Anular este token podría evitar el borrado de tu dispositivo si no ha empezado todavía.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} iOS app",
    "{productName} Android app" : "{productName} Android app",
    "{productName} Talk for iOS" : "{productName} Talk for iOS",
    "{productName} Talk for Android" : "{productName} Talk for Android",
    "Sync client - {os}" : "Cliente de sincronización - {os}",
    "This session" : "Esta sesión",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Devices & sessions" : "Dispositivos y sesiones",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, móviles y de escritorio actualmente conectados a tu cuenta.",
    "Do you really want to wipe your data from this device?" : "¿Estás seguro de querer borrar tus datos de este dispositivo?",
    "Confirm wipe" : "Confirmar borrado",
    "Error while creating device token" : "Error al crear \"token\" de dispositivo",
    "Error while updating device token scope" : "Error al actualizar el alcance del token de dispositivo",
    "Error while updating device token name" : "Error al actualizar el nombre del token de dispositivo",
    "Error while deleting the token" : "Error al eliminar el \"token\"",
    "Error while wiping the device with the token" : "Error al borrar el dispositivo con el token",
    "App name" : "Nombre de la app",
    "Create new app password" : "Crear nueva contraseña de app",
    "Use the credentials below to configure your app or device." : "Use las siguientes credenciales para configurar su app o dispositivo.",
    "For security reasons this password will only be shown once." : "Para seguridad, esta contraseña será mostrada solamente una vez.",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Done" : "Hecho",
    "Show QR code for mobile apps" : "Mostrar código QR para apps móviles",
    "Copied!" : "¡Copiado!",
    "Copy" : "Copiar",
    "Could not copy app password. Please copy it manually." : "No se ha podido copiar la contraseña de app. Por favor, cópiala manualmente.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Para que el servidor trabaje bien, es importante configurar correctamente los trabajos en segundo plano. La configuración recomendada es cron. Por favor, ver la documentación para más información.",
    "Last job execution ran {time}. Something seems wrong." : "La última ejecución de un trabajo fue {time}. Algo parece ir mal. ",
    "Last job ran {relativeTime}." : "Último trabajo realizado {relativeTime}.",
    "Background job did not run yet!" : "¡El trabajo en segundo plano no se ha ejecutado todavía!",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "Ejecutar una tarea con cada página cargada. Caso de uso: Instancia de un solo usuario.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php se registra en un servicio webcron para llamar a cron.php cada 5 minutos a través de HTTP. Caso de uso: Instancia muy pequeña (1-5 usuarios dependiendo del uso).",
    "Cron (Recommended)" : "Cron (Recomendado)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Necesitas la extensión PHP POSIX para lanzar esto. Mira la {linkstart}documentación de PHP{linkend} para más detalles.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Usa el servicio cron del sistema para llamar al archivo cron.php cada 5 minutos. Recomendado para todas las instancias.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "El archivo cron.php debe ser ejecutado por el usuario de sistema  \"{user}\".",
    "Unable to update background job mode" : "No se puede actualizar el modo de trabajo en segundo plano",
    "Profile" : "Perfil",
    "Enable or disable profile by default for new users." : "Activar o desactivar el perfil por defecto para los nuevos usuarios.",
    "Enable" : "Activar",
    "Unable to update profile default setting" : "No se pudo actualizar la configuración por defecto del perfil",
    "Server-side encryption" : "Cifrado en el servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "El cifrado en el servidor hace posible cifrar archivos que se suben a este servidor. Esto trae consigo limitaciones como una ralentización en su funcionamiento, así que activa esto solo si es necesario.",
    "Enable server-side encryption" : "Habilitar cifrado en el servidor",
    "Please read carefully before activating server-side encryption:" : "Por favor, lea atentamente antes de activar el cifrado en el servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que el cifrado está habilitado, todos los archivos subidos al servidor desde ese punto en adelante se cifrarán en reposo en el servidor. Sólo será posible desactivar el cifrado en una fecha posterior si el módulo de cifrado activado soporta esa función, y todas las condiciones (por ejemplo, el establecimiento de una clave de recuperación) se cumpen.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "El cifrado no garantiza por sí solo la seguridad del sistema. Por favor, vea la documentación para más información sobre cómo funciona la app de cifrado y los casos de uso soportados.",
    "Be aware that encryption always increases the file size." : "Tenga presente que la encripción siempre incrementa el tamaño del archivo.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es bueno crear copias de seguridad de sus datos, en el caso del cifrado, asegúrese de tener una copia de seguridad de las claves de cifrado junto con sus datos.",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final. ¿Realmente quiere activar el cifrado?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado el modulo de cifrado. Por favor habilite un modulo de cifrado en el menú de aplicaciones.",
    "Select default encryption module:" : "Seleccione el módulo de cifrado por defecto:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Necesita migrar sus claves de cifrado provenientes del antiguo sistema (ownCloud <= 8.0) al nuevo. Por favor, habilite el \"Módulo de cifrado por defecto\" y ejecute {command}",
    "Unable to update server side encryption config" : "No ha sido posible actualizar la configuración de cifrado del lado del servidor",
    "Rename group" : "Renombrar grupo",
    "Remove group" : "Eliminar grupo",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Vas a eliminar el grupo {group}. Los usuarios NO serán eliminados.",
    "Please confirm the group removal " : "Por favor, confirma la eliminación del grupo",
    "Current password" : "Contraseña actual",
    "New password" : "Nueva contraseña",
    "Change password" : "Cambiar contraseña",
    "Your profile picture" : "Su imagen de perfil",
    "Upload profile picture" : "Subir imagen del perfil",
    "Choose profile picture from files" : "Seleccionar imagen del perfil desde los archivos",
    "Remove profile picture" : "Eliminar imagen del perfil",
    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
    "Picture provided by original account" : "Imagen provista por la cuenta original",
    "Cancel" : "Cancelar",
    "Set as profile picture" : "Establecer como imagen del perfil",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tenga en cuenta que puede tomar hasta 24 horas para que su imagen del perfil sea actualizada en todas partes",
    "Choose your profile picture" : "Seleccione su imagen de perfil",
    "Please select a valid png or jpg file" : "Por favor, seleccione un archivo png o jpg válido",
    "Error setting profile picture" : "Error configurando imagen del perfil",
    "Error cropping profile picture" : "Error recortando imagen del perfil",
    "Error saving profile picture" : "Error guardando imagen del perfil",
    "Error removing profile picture" : "Error eliminando imagen del perfil",
    "Your biography" : "Tu biografía",
    "Details" : "Detalles",
    "You are a member of the following groups:" : "Eres miembro de los siguientes grupos:",
    "You are using <strong>{usage}</strong>" : "Estás usando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Estás usando <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "Your full name" : "Tu nombre completo",
    "Email options" : "Opciones de email",
    "Primary email for password reset and notifications" : "Dirección email principal para restablecer contraseña y notificaciones",
    "Remove primary email" : "Borrar email principal",
    "Delete email" : "Borrar email",
    "Unset as primary email" : "Quitar como email principal",
    "This address is not confirmed" : "Esta dirección no está confirmada",
    "Set as primary email" : "Establecer como email principal",
    "Your email address" : "Su dirección de correo",
    "Additional email address {index}" : "Direcciones email adicionales {index}",
    "Unable to delete primary email address" : "No se pudo borrar tu dirección de email principal",
    "Unable to update primary email address" : "No se pudo actualizar tu dirección de email principal",
    "Unable to add additional email address" : "No se pudo añadir una dirección de email adicional",
    "Unable to update additional email address" : "No se pudo actualizar la dirección de email adicional",
    "Unable to delete additional email address" : "No se pudo borrar la dirección de email adicional",
    "No email address set" : "No hay establecida ninguna dirección de correo",
    "Additional emails" : "Direcciones de email adicionales",
    "Your headline" : "Tu titular",
    "Language" : "Idioma",
    "Help translate" : "Ayúdanos a traducir",
    "Unable to update language" : "No se pudo actualizar tu idioma",
    "No language set" : "No se ha marcado idioma",
    "Locale" : "Región",
    "Week starts on {firstDayOfWeek}" : "La semana comienza en {firstDayOfWeek}",
    "Unable to update locale" : "Imposible actualizar el idioma",
    "No locale set" : "No se ha establecido el idioma",
    "Your location" : "Su ubicación",
    "Your organisation" : "Tu organización",
    "Your phone number" : "Su número de teléfono",
    "Edit your Profile visibility" : "Editar la visibilidad de tu perfil",
    "Enable Profile" : "Activar Perfil",
    "Unable to update profile enabled state" : "No se pudo actualizar el estado habilitado del perfil",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Se respetará en tu perfil el ajuste más restrictivo entre visibilidad y alcance. Por ejemplo, si la visibilida está configurada en \"Mostrar a todos\" y el alcance en \"Privado\", los ajustes de \"Privado\" se respetarán.",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "No se pudo actualizar la visibilidad de {displayId}",
    "Your role" : "Tu rol",
    "Your Twitter handle" : "Su usuario de Twitter",
    "Your website" : "La dirección de su sitio web",
    "No {property} set" : "No se ha establecido {property}",
    "Unable to update {property}" : "Imposible actualizar {property}",
    "Change scope level of {property}, current scope is {scope}" : "Cambiar el nivel de privacidad de {property}, el valor actual es {scope}",
    "Unable to update federation scope of the primary {property}" : "No se puede actualizar el alcance de federación del principal {property}",
    "Unable to update federation scope of additional {property}" : "No se puede actualizar el alcance de federación adicional de {property}",
    "Add additional email" : "Añadir un email adicional",
    "Add" : "Añadir",
    "You do not have permissions to see the details of this user" : "No tienes permisos para ver los detalles de este usuario",
    "Add new password" : " Añadir nueva contraseña",
    "Add new email address" : "Añadir nueva dirección de correo electrónico",
    "Add user to group" : "Añadir usuario a grupo",
    "Set user as admin for" : "Marcar usuario como administrador para",
    "Select user quota" : "Seleccionar cuota de usuario",
    "Delete user" : "Eliminar usuario",
    "Wipe all devices" : "Borrar todos los dispositivos",
    "Disable user" : "Inhabilitar usuario",
    "Enable user" : "Habilitar usuario",
    "Resend welcome email" : "Volver a enviar correo de bienvenida",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En caso de pérdida del dispositivo o dejar la organización, esto puede eliminar remotamente los datos de Nextcloud de todos los dispositivos asociados con {userid}. Nota: sólo funciona si los dispositivos están conectados a Internet.",
    "Remote wipe of devices" : "Eliminación remota de dispositivos",
    "Wipe {userid}'s devices" : "Eliminar dispositivos de {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar completamente la cuenta de {userid}, incluyendo todos sus archivos personales, datos de las apps, etc.",
    "Account deletion" : "Eliminación de la cuenta",
    "Delete {userid}'s account" : "Eliminar cuentas de {userid}",
    "Welcome mail sent!" : "¡Correo de bienvenida enviado!",
    "Edit User" : "Editar usuario",
    "Toggle user actions menu" : "Alternar el menú de acciones del usuario",
    "{size} used" : "{size} usados",
    "New user" : "Nuevo usuario",
    "Will be autogenerated" : "Se generará de forma automática",
    "Display name" : "Nombre para mostrar",
    "Email" : "Correo electrónico",
    "Default language" : "Idioma predeterminado",
    "Add a new user" : "Añadir nuevo usuario",
    "Group admin for" : "Administrador de grupo para",
    "Quota" : "Espacio asignado",
    "User backend" : "Motor de usuario",
    "Storage location" : "Ubicación de los datos",
    "Last login" : "Último inicio de sesión",
    "No users in here" : "No hay usuarios aquí",
    "Default quota" : "Espacio predefinido",
    "Common languages" : "Idiomas habituales",
    "Other languages" : "Otros idiomas",
    "Password change is disabled because the master key is disabled" : "El cambio de contraseña está desactivado porque la clave maestra está desactivada",
    "Passwordless authentication requires a secure connection." : "La autenticación sin contraseña requiere una conexión segura.",
    "Add WebAuthn device" : "Añadir dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorice a su dispositivo WebAuthn, por favor.",
    "Name your device" : "Nombre de tu dispositivo",
    "Adding your device …" : "Añadiendo tu dispositivo...",
    "Server error while trying to add WebAuthn device" : "Error del servidor al intentar añadir el dispositivo WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Error del servidor al intentar completar el registro del dispositivo WebAuthn",
    "Unnamed device" : "Dispositivo sin nombre",
    "Passwordless Authentication" : "Autenticación sin contraseña",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configure su cuenta para autenticarla sin contraseña siguiendo el estándar FIDO2.",
    "No devices configured." : "No hay dispositivos configurados.",
    "The following devices are configured for your account:" : "Los siguientes dispositivos están configurados en su cuenta:",
    "Your browser does not support WebAuthn." : "Tu navegador no soporta WebAuthn.",
    "Your apps" : "Tus apps",
    "Active apps" : "Apps activas",
    "Disabled apps" : "Apps deshabilitadas",
    "Updates" : "Actualizaciones",
    "App bundles" : "Lotes de apps",
    "Featured apps" : "Apps destacadas",
    "{license}-licensed" : "licenciado bajo {license}",
    "Changelog" : "Historial de cambios",
    "by {author}\n{license}" : "por {author}\n{license}",
    "Enter group name" : "Introduce el nombre del grupo",
    "Add group" : "Añadir grupo",
    "Active users" : "Usuarios activos",
    "Admins" : "Administradores",
    "Disabled users" : "Usuarios inhabilitados",
    "Default quota:" : "Espacio por defecto:",
    "Select default quota" : "Seleccionar espacio por defecto",
    "Show Languages" : "Mostrar idiomas",
    "Show last login" : "Mostrar último inicio de sesión",
    "Show user backend" : "Mostrar motor de usuario",
    "Show storage path" : "Mostrar ruta de almacenamiento",
    "Send email to new user" : "Enviar correo al usuario nuevo",
    "Not saved" : "No guardado",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Location" : "Ubicación",
    "Profile picture" : "Foto de perfil",
    "About" : "Acerca de",
    "Full name" : "Nombre completo",
    "Additional email" : "Email adicional",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Phone number" : "Número de teléfono",
    "Role" : "Cargo",
    "Twitter" : "Twitter",
    "Website" : "Sitio web",
    "Profile visibility" : "Visibilidad del perfil",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No está disponible, ya que esta característica es necesaria para la funcionalidad principal, incluyendo el intercambio de archivos y las invitaciones de calendario",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No está disponible ya que la federación ha sido deshabilitada para su cuenta, contacte a su administrador del sistema si tiene cualquier pregunta",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No está disponible ya que la publicación de datos específicos del usuario en el servidor de búsqueda no está permitida, póngase en contacto con el administrador del sistema si tiene alguna duda",
    "Show to everyone" : "Mostrar a todos",
    "Show to logged in users only" : "Mostrar solo a usuarios con inicio de sesión",
    "Hide" : "Ocultar",
    "Download and enable" : "Descargar y activar",
    "Enable untested app" : "Activar app no probada",
    "The app will be downloaded from the App Store" : "La app va a ser descargada de la App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta app no está marcada como compatible con tu versión de Nextcloud. Si continúas podrás instalar la app, pero ten en cuenta que podría no funcionar según lo esperado.",
    "Never" : "Nunca",
    "An error occurred during the request. Unable to proceed." : "Ha ocurrido un error durante la solicitud. No se puede continuar.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La app ha sido activada pero tiene que actualizarse. Serás redirigido a la página de actualización en 5 segundos.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta app no se puede activar porque hace inestable al servidor",
    "Administrator documentation" : "Documentación del adminsitrador",
    "Documentation" : "Documentación",
    "Forum" : "Foro",
    "Login" : "Iniciar sesión",
    "Plain" : "Plano",
    "NT LAN Manager" : "Gestor de NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante configurar este servidor para que pueda enviar correos, por ejemplo para cambios de contraseñas y notificaciones.",
    "Send mode" : "Modo de envío",
    "Encryption" : "Cifrado",
    "Sendmail mode" : "Modo Sendmail",
    "From address" : "Desde la dirección",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Se necesita autenticación",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "Nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Save" : "Guardar",
    "Test and verify email settings" : "Comprobar y verificar configuración de correo",
    "Send email" : "Enviar mensaje",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Es importante para la seguridad y rendimiento de tu instancia que todo esté correctamente configurado. Para ayudarte con ello estamos haciendo algunas comprobaciones automáticas. Para más información, por favor comprueba la documentación enlazada.",
    "All checks passed." : "Ha pasado todos los controles",
    "There are some errors regarding your setup." : "Hay varios errores relativos a su configuración.",
    "There are some warnings regarding your setup." : "Hay varios avisos relativos a su configuración.",
    "Checking for system and security issues." : "Comprobando problemas en el sistema y de seguridad.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Por favor, vuelve a consultar las <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guías de instalación ↗</a>, y comprueba posibles errores y advertencias en el <a href=\"%2$s\">registro</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Compruebe la seguridad de su Nextcloud mediante <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nuestro escaneo de seguridad ↗</a>.",
    "Version" : "Versión",
    "You need to enable the File sharing App." : "Tienes que activar la app File sharing",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador puedes ajustar el comportamiento de compartir. Por favor, lea la documentación para más información.",
    "Allow apps to use the Share API" : "Permitir a las aplicaciones utilizar la API de Compartir",
    "Set default expiration date for shares" : "Establecer fecha de caducidad predeterminada para recursos compartidos",
    "Expire after" : "Caduca después del",
    "day(s)" : "día(s)",
    "Enforce expiration date" : "Imponer fecha de caducidad",
    "Set default expiration date for shares to other servers" : "Establecer fecha de caducidad predeterminada para recursos compartidos con otros servidores",
    "Allow users to share via link and emails" : "Permitir a los usuarios compartir a través de enlaces y emails",
    "Allow public uploads" : "Permitir subidas públicas",
    "Always ask for a password" : "Pedir siempre la contraseña",
    "Enforce password protection" : "Forzar la protección por contraseña.",
    "Exclude groups from password requirements:" : "Excluir a los grupos de los requisitos de contraseña:",
    "Set default expiration date" : "Establecer fecha de caducidad predeterminada",
    "Exclude groups from creating link shares:" : "Excluir a los grupos de la creación de enlaces compartidos:",
    "Allow resharing" : "Permitir que se vuelva a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a compartir solo con los usuarios de sus grupos",
    "Exclude groups from sharing" : "Excluye grupos de compartir",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir contenidos compartidos, pero no podrán iniciarlos.",
    "Allow username autocompletion in share dialog" : "Permitir autocompletar nombre de usuario en la casilla de compartir",
    "Allow username autocompletion to users within the same groups" : "Permitir autocompletar nombre de usuario a los usuarios del mismo grupo",
    "Allow username autocompletion to users based on phone number integration" : "Permitir autocompletar nombre de usuario a usuarios basado en la integración del número de teléfono",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Si el autocompletado \"en mismo grupo\" e \"integración del número de telefono\" están activados, una coincidencia en cualquiera de ellos es suficiente para mostrar un usuario.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir autocompletado del nombre de usuario cuando se introduzca el nombre completo o la dirección del email (ignorando la falta de coincidencia en la agenda de teléfonos y ser del mismo grupo)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostrar texto de aviso en la página de subida de enlace público (solo se muestra cuando la lista de archivos está oculta)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de subida de enlace público cuando la lista de archivos esté oculta.",
    "Default share permissions" : "Permisos para compartir por defecto",
    "Reasons to use Nextcloud in your organization" : "Razones para usar Nextcloud en su organización",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la {communityopen}comunidad Nextcloud{linkclose}, el {githubopen}código fuente{linkclose} está bajo la licencia  {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Da a Me gusta en nuestra página de Facebook",
    "Follow us on Twitter" : "Síguenos en Twitter",
    "Follow us on Mastodon" : "Síguenos en Mastodon",
    "Check out our blog" : "Lee nuestro blog",
    "Subscribe to our newsletter" : "Suscríbete a nuestro boletín",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
    "Use a second factor besides your password to increase security for your account." : "Usa un segundo paso además de tu contraseña para incrementar la seguridad de tu cuenta. ",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utiliza aplicaciones de terceras partes para conectarse a Nextcloud, por favor compruebe que crea y configura una contraseña de app para cada una antes de activar el factor de autentificación de dos pasos.",
    "Migration in progress. Please wait until the migration is finished" : "Migración en curso. Por favor, espere hasta que la migración esté finalizada.",
    "Migration started …" : "Migración iniciada...",
    "An error occurred while changing your language. Please reload the page and try again." : "Ha ocurrido un error al cambiar tu idioma. Por favor, recarga la página y vuelve a intentarlo.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Ha ocurrido un error al cambiar tu región. Por favor, recarga la página y vuelve a intentarlo.",
    "Select a profile picture" : "Seleccionar una imagen de perfil",
    "Week starts on {fdow}" : "La semana empieza el {fdow}",
    "Couldn't remove app." : "No se ha podido eliminar la aplicación.",
    "Couldn't update app." : "No se ha podido actualizar la aplicación.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El sistema no permite cambiar la contraseña, pero la clave de cifrado ha sido actualizada.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "No se puede determinar si la versión TLS de cURL está anticuada o no debido a que ocurrió un error durante la consulta HTTPS contra https://nextcloud.com. Por favor compruebe el archivo de registro de nexcloud para más detalles.",
    "You need to set your user email before being able to send test emails." : "Tienes que configurar tu dirección de correo electrónico antes de poder enviar mensajes de prueba.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Anular este token puede evitar el borrado de tu dispositivo si aún no se ha iniciado el borrado.",
    "Set as primary mail" : "Establecer como email principal",
    "Change privacy level of email" : "Cambiar nivel de privacidad del email",
    "All languages" : "Todos los idiomas",
    "Everyone" : "Todos",
    "An error occured during the request. Unable to proceed." : "Ha ocurrido un error durante la petición. No se puede continuar.",
    "Test email settings" : "Probar configuración del correo electrónico",
    "Please read carefully before activating server-side encryption: " : "Por favor, lea cuidadosamente antes de activar el cifrado en el servidor.",
    "Enable encryption" : "Habilitar cifrado",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesita migrar sus claves de cifrado provenientes del antiguo sistema (ownCloud <= 8.0) al nuevo. Por favor habilite el \"Módulo de cifrado por defecto\" y ejecute 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Se necesita migrar las claves de cifrado del antiguo sistema (ownCloud <= 8.0) al nuevo sistema.",
    "Start migration" : "Iniciar migración",
    "Last job execution ran %s. Something seems wrong." : "La última ejecución de un trabajo fue %s. Algo parece ir mal.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Algunos trabajos no se han ejecutado desde %s. Por favor, considere aumentar la frecuencia de ejecución.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Algunos trabajajos no se ejecutaron desde %s. Por favor, considere cambiar al sistema 'cron'.",
    "Last job ran %s." : "El último trabajo se ejecutó %s.",
    "Background job didn’t run yet!" : "¡El trabajo en segundo plano no se ha ejecutado todavía!",
    "For the server to work properly, it's important to configure background jobs correctly. \"Cron\" is the recommended setting. Please see the documentation for more information." : "Para un rendimiento óptimo es importante configurar correctamente los procesos en segundo plano. Para las instancias más grandes la configuración recomendada es 'Cron'. Por favor, lea la documentación para más información.",
    "Pick background job setting" : "Escoge la configuración de las tareas en segundo plano",
    "Recommended" : "Recomendado",
    "The cron.php needs to be executed by the system user \"%s\"." : "El archivo cron.php debe ser ejecutado por el usuario de sistema \"%s\".",
    "days" : "días",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Permitir autocompletado del nombre de usuario cuando se introduzca el nombre completo o la dirección del email (ignorando la falta de coincidencia en la agenda de teléfonos y ser del mismo grupo)",
    "Change privacy level of profile picture" : "Cambiar nivel de privacidad de la imagen de perfil",
    "Upload new" : "Subir nueva",
    "Select from Files" : "Seleccionar desde Archivos",
    "Remove image" : "Borrar imagen",
    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Ten en cuenta que el avatar puede tardar hasta 24 horas en actualizarse en todas partes.",
    "Choose as profile picture" : "Seleccionar como imagen de perfil",
    "You are using <strong>%s</strong>" : "Estás usando <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Estás usando <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
    "Change privacy level of full name" : "Cambiar nivel de privacidad del nombre completo",
    "No display name set" : "No se ha establecido ningún nombre para mostrar",
    "Change privacy level of phone number" : "Cambiar nivel de privacidad del número de teléfono",
    "Address" : "Dirección",
    "Change privacy level of address" : "Cambiar nivel de privacidad de la dirección",
    "Your postal address" : "Su dirección física",
    "Change privacy level of website" : "Cambiar nivel de privacidad de la página web",
    "It can take up to 24 hours before the account is displayed as verified." : "Puede tardar hasta 24 horas que la cuenta aparezca como verificada.",
    "Link https://…" : "Enlace https://...",
    "Change privacy level of Twitter profile" : "Cambiar nivel de privacidad del perfí en Twitter",
    "Twitter handle @…" : "Usuario de Twitter @...",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "El número máximo de claves de OPcache está casi superado. Para asegurar que todos los scripts puedan mantenerse en la caché, se recomienda aplicar  <code>opcache.max_accelerated_files</code> a su configuración de PHP con un valor superior a <code>%s</code>.",
    "Admin privileges" : "Privilegios del administrador",
    "Unable to update biography" : "No se pudo actualizar la biografía",
    "Unable to update full name" : "No se pudo actualizar tu nombre completo",
    "No full name set" : "No se ha completado el nombre completo",
    "Unable to update headline" : "No se pudo actualizar tu titular",
    "Unable to update organisation" : "No se pudo actualizar tu organización",
    "Unable to update role" : "No se pudo actualizar el cargo",
    "Change scope level of {accountProperty}" : "Cambiar el nivel de privacidad de {accountProperty}",
    "Unable to update federation scope of the primary {accountProperty}" : "No se puede actualizar el perímetro de la federación del principal {accountProperty}",
    "Unable to update federation scope of additional {accountProperty}" : "No se puede actualizar el perímetro de la federación de la adicional {accountProperty}",
    "Avatar" : "Avatar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
